@@ -4,6 +4,9 @@
 
 void init_location(py::module_ &m) {
 
+  py::class_<vroom::Coordinates>(m, "Coordinates")
+    .def(py::init<vroom::Coordinate, vroom::Coordinate>(), py::arg("lon"), py::arg("lat"));
+
   py::class_<vroom::Location>(m, "Location")
       .def(py::init<vroom::Index>(), py::arg("index"))
       .def(py::init<vroom::Coordinates>(), py::arg("coords"))
